# Django Pathfinder Statcrunch
Pathfinder statistics crunching tool.


# Features
* Display character statistics that include alternate characters
* Display corporation statistics for multi-corporation alliances

